@@ -1,7 +1,15 @@
 import ast
 import textwrap
+import os.path
+def importerror(filename,cmd):
+    if os.path.exists(filename):
+        return
+    else:
+        print("Error 3: No File Found with Name ",filename," in ",cmd)
+        exit()
 def load_file_as_function(file_path):
     # Open the file for reading
+    importerror(file_path, "model_load()")
     with open(file_path, 'r') as file:
         # Read the contents of the file
         file_contents = file.read()
@@ -16,6 +24,7 @@ def load_file_as_function(file_path):
 def modeltype_load(modelfile,word,wordslist1,wordslist2):
     global words_list1
     global words_list2
+
     loaded_func = load_file_as_function(modelfile)
     return loaded_func(word,wordslist1,wordslist2)
 
@@ -24,6 +33,3 @@ def modeltype_load(modelfile,word,wordslist1,wordslist2):
 
 
 
-
-
-
